<?php
/*
  Plugin Name: WordiZ - Most Shared Articles for Authors
  Description: Display authorship based 'most shared articles' in a <a href="widgets.php">widget</a>. Please, create an account on <a href="http://www.wordiz.it">WordiZ</a> to get your data collected prior using the widget.
  Author: <a href="http://boiteaweb.fr">Julio Potier</a>, <a href="http://www.wordiz.it">WordiZ</a> 
  Version: 1.0.2
  Author URI: http://boiteaweb.fr
  Licence: GPLv2
 */

add_action( 'plugins_loaded', 'baw_load_langs_wordiz_widget' );
function baw_load_langs_wordiz_widget()
{
    load_plugin_textdomain( 'baw_wordiz_widget', false, dirname(plugin_basename(__FILE__)) . '/langs/' );
    wp_register_style( 'wordiz',  plugins_url( '/wordiz_widget.css', __FILE__ ) );
}

// register Wordiz_Widget widget
add_action( 'widgets_init', 'baw_register_wordiz_widget' );
function baw_register_wordiz_widget()
{
    register_widget( 'baw_wordiz_widget' );
}

function baw_wordiz_widget_admin_scripts(){
	?>
	<style type="text/css">
		.wordiz_support{
			border: 1px solid #DFDFDF;
			padding: 5px 13px;
			background: #F9F9F9;
			text-decoration:none;
			margin: 10px -13px;
		}
		.wordiz_support a{
			text-decoration: none;
		}
		.wordiz_support a:hover{
			text-decoration: underline;
		}
	</style>
	<?php
}
add_action('sidebar_admin_page', 'baw_wordiz_widget_admin_scripts');

class BAW_Wordiz_Widget extends WP_Widget {

    function __construct() {

        $widget_args = array(
            'classname'   => 'baw_wordiz_widget',
            'description' => __( 'Display  \'most shared articles\' based on authorship tag.', 'baw_wordiz_widget' )
        );

        parent::__construct( 'baw_wordiz_widget', __( 'WordiZ Widget - Authorship Best articles', 'baw_wordiz_widget' ), $widget_args );
    }

    function widget( $arguments, $instance ) {

        extract( $arguments );

        $title       = apply_filters( 'widget_title', $instance['title'] );
        $width       = !$instance['width'] ? '' : (int)$instance['width'];
        $class       = 'bright' == $instance['style'] ? 'bright' : 'dark';
        $follow      = 'do' == $instance['follow'] ? 'do' : 'no';
        $item_number = esc_attr( $instance['item_number'] );
        $user_id     = esc_attr( $instance['user_id'] );
        $from_cache = true;

        if( !$json = get_transient( 'wordiz_' . $user_id ) )
        {
            $json = wp_remote_get( 'http://www.wordiz.it/profile/widget_author/'.$user_id.'.json/' );
            $from_cache  = false;
        }

        if( $from_cache || ( !is_wp_error( $json ) && $json = wp_remote_retrieve_body( $json ) ) )
        {
            $json = json_decode( $json );
            if( !isset( $json->Error ) ) {
                set_transient( 'wordiz_' . $user_id, json_encode( $json ), 3*DAY_IN_SECONDS );
                wp_enqueue_style( 'wordiz' );
                echo $before_widget;

                echo !empty( $title ) ? $before_title . $title . $after_title : '';
                ?>
                <div id="wordiz_author_widget_container_<?php echo $user_id; ?>" class="wordiz_author_widget" data-width="<?php echo $width; ?>" data-style="<?php echo $style; ?>" data-item_number="<?php echo $item_number; ?>" data-userid="<?php echo $user_id; ?>"></div>
                <ul class="widget <?php echo $class; ?>" style="width:<?php echo $width; ?>;">
                <?php
                    foreach ($json->top_articles as $n=>$article )
                    {
                        if( $n==$item_number )
                            break;
                        $the_prop = '';
                        $props = array( 'title'=>esc_attr( $article->title ), 'href'=>esc_url( $article->url ), 'target'=>'_blank' );
                        if( 'no'==$follow )
                            $props['rel'] = 'nofollow';
                        $props = apply_filters( 'wordiz_a_props', $props, $article );
                        foreach( $props as $prop=>$val )
                            $the_prop .= "{$prop}=\"{$val}\" ";
                        echo '<li>';
                            echo "<a {$the_prop}>". esc_html( $article->title ) .'</a><br />';
                            echo '<span class="wordiz_widget twitter">' . (int)$article->tweet_count .'</span>';
                            echo '<span class="wordiz_widget google">' . (int)$article->plus_google .'</span>';
                            echo '<span class="wordiz_widget facebook">' . (int)$article->like_count .'</span>';
                        echo '</li>';
                    }
                ?>
                </ul>
                <?php
                echo $after_widget;
            }else{
                echo esc_html( str_replace( '.', ' : ' . esc_html( $user_id ), $json->Error ) );
            }
        }
    }

    function update( $new_instance, $old_instance ) {

        $instance = $old_instance;

        $instance['title']       = sanitize_text_field( $new_instance['title'] );
        $instance['width']       = intval( $new_instance['width'] ) > 0 ? intval( $new_instance['width'] ) : 'auto';
        $instance['style']       = 'bright' == $new_instance['style'] ? 'bright' : 'dark';
        $instance['follow']      = 'no' == $new_instance['follow'] ? 'no' : 'do';
        $instance['item_number'] = (int)$new_instance['item_number'] > 0 && (int)$new_instance['item_number'] <= 5 ? (int)$new_instance['item_number'] : (int)$old_instance['item_number'];
        $instance['user_id']     = str_replace( '^([0-9])+$', '', $new_instance['user_id'] );

        return $instance;
    }

    function form( $instance ) {

        $defaults = array(
            'title'       => '',
            'width'       => 250,
            'follow'      => 'do',
            'style'       => 'bright',
            'item_number' => 5,
            'user_id'     => ''
        );

        $instance = wp_parse_args( (array)$instance, $defaults );

        $follow      = esc_attr( $instance['follow'] );
        $title       = esc_attr( $instance['title'] );
        $width       = esc_attr( $instance['width'] );
        $style       = esc_attr( $instance['style'] );
        $item_number = esc_attr( $instance['item_number'] );
        $user_id     = esc_attr( $instance['user_id'] );
        ?>

<div class="wordiz_support"><p>Before using the plugin, you need to register on <a href="http://www.wordiz.it">WordiZ</a> (it is only a one click registration). It will allow your articles to be analyzed.</p></div>


            <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title', 'baw_wordiz_widget'); ?> :</label>
            <input value="<?php echo $title; ?>" type="text" name="<?php echo $this->get_field_name('title'); ?>" class="widefat" id="<?php echo $this->get_field_id('title'); ?>" />
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('width'); ?>"><?php _e('Width (in pixels)', 'baw_wordiz_widget'); ?> :</label>
            <input value="<?php echo $width; ?>" type="text" name="<?php echo $this->get_field_name('width'); ?>" class="widefat" id="<?php echo $this->get_field_id('width'); ?>" />
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('style'); ?>"><?php _e('Display on bright or dark background ?', 'baw_wordiz_widget'); ?> :</label>
            <select name="<?php echo $this->get_field_name('style'); ?>" id="<?php echo $this->get_field_id('style'); ?>" class="widefat">
                <option <?php selected( $style, 'bright', true ); ?> value="bright"><?php _e('Bright', 'baw_wordiz_widget'); ?></option>
                <option <?php selected( $style, 'dark', true ); ?> value="dark"><?php _e('Dark', 'baw_wordiz_widget'); ?></option>
            </select>
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('item_number'); ?>"><?php _e('Number of items', 'baw_wordiz_widget'); ?> :</label>
            <select name="<?php echo $this->get_field_name('item_number'); ?>" id="<?php echo $this->get_field_id('item_number'); ?>" class="widefat">
                <?php for ($i = 1; $i <= $defaults['item_number']; $i++) : ?>
                    <option <?php selected( $item_number, $i, true ); ?> value="<?php echo $i; ?>"><?php echo $i; ?></option>
                <?php endfor; ?>
            </select>
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('follow'); ?>"><?php _e('Follow or Nofollow?', 'baw_wordiz_widget'); ?> :</label>
            <select name="<?php echo $this->get_field_name('follow'); ?>" id="<?php echo $this->get_field_id('follow'); ?>" class="widefat">
                <option <?php selected( $follow, 'do', true ); ?> value="do"><?php _e( 'dofollow links', 'baw_wordiz_widget' ); ?></option>
                <option <?php selected( $follow, 'no', true ); ?> value="no"><?php _e( 'nofollow links', 'baw_wordiz_widget' ); ?></option>
            </select>
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('user_id'); ?>"><?php _e('Google+ User ID', 'baw_wordiz_widget'); ?> :</label>
            <input value="<?php echo $user_id; ?>" type="text" name="<?php echo $this->get_field_name('user_id'); ?>" class="widefat" id="<?php echo $this->get_field_id('user_id'); ?>" />
        </p>

        <div class="wordiz_support"> Your Google+ id could be found very easily : visit your Google+ profile page (<a href="https://plus.google.com/u/0/me?tab=XX" rel="nofollow">https://plus.google.com/u/0/me?tab=XX</a>) and pass the mouse over your name. </p>
        <p>
        There should be a link with several digits like : <a href="https://plus.google.com/113400244614302404694" rel="nofollow">https://plus.google.com/113400244614302404694</a> . Your google+ id should be : 113400244614302404694</p>
		<p><small style="opacity: 0.7"><a href="http://wordpress.org/support/view/plugin-reviews/wordiz-most-shared-articles-for-authors?filter=5" target="_blank">Support</a> | <a href="https://twitter.com/WordiZit" target="_blank">Follow</a></small></p>		</div>
        <?php
    }
}